@@ -5,11 +5,16 @@ pd.set_option("display.float_format", lambda x: "%.7f" % x)
 def html_to_df(page_source):
     """
 
+    :param page_source:
+    :returns:
     """
     tables = pd.read_html(page_source, decimal=",", thousands=".")[:-1]
     df = pd.concat(tables, axis=0, ignore_index=True)
     cols = df.columns
     df = df.drop([cols[2], cols[3], cols[8]], axis=1)
+    colss = df.columns
+    discard = [" TR"]
+    df = df[~df[colss[0]].str.contains('|'.join(discard))]
 
     for col in df.columns[1:]:
         df[col] = df[col].astype(str).str.replace(" ", "")
@@ -29,8 +34,5 @@ def html_to_df(page_source):
         columns_new.append(column.replace("▲", "").replace("▼", "").strip())
 
     df.columns = columns_new
-        
-    # print("")
-    # print(df.dtypes)
 
     return df
